==> apache-cxf-3.4.7-src.tar.gz: apache-cxf-3.4.7-src/rt/databinding/jaxb/src/test/java/org/apache/cxf/jaxb/fortest/QualifiedBean.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.jaxb.fortest;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;

@XmlRootElement(namespace = "uri:ultima:thule")
public class QualifiedBean {
    private String ariadne;

    public String getAriadne() {
        return ariadne;
    }

    public void setAriadne(String ariadne) {
        this.ariadne = ariadne;
    }

    @XmlAttribute
    public String getDefaultAttribute() {
        return "default";
    }

    public void setDefaultAttribute(String val) {
        //
    }


    @XmlAttribute(namespace = "")
    public String getEmptyNamespaceAttribute() {
        return "empty";
    }

    public void setEmptyNamespaceAttribute() {
    }

    @XmlAttribute(namespace = "urn:xyzzy")
    public String getExplicitNamespaceAttribute() {
        return "explicit";
    }

    public void setExplicitNamespaceAttribute() {
    }
}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/rt/databinding/jaxb/src/test/java/org/apache/cxf/jaxb/fortest/QualifiedBean.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.jaxb.fortest;

import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlRootElement;

@XmlRootElement(namespace = "uri:ultima:thule")
public class QualifiedBean {
    private String ariadne;

    public String getAriadne() {
        return ariadne;
    }

    public void setAriadne(String ariadne) {
        this.ariadne = ariadne;
    }

    @XmlAttribute
    public String getDefaultAttribute() {
        return "default";
    }

    public void setDefaultAttribute(String val) {
        //
    }


    @XmlAttribute(namespace = "")
    public String getEmptyNamespaceAttribute() {
        return "empty";
    }

    public void setEmptyNamespaceAttribute() {
    }

    @XmlAttribute(namespace = "urn:xyzzy")
    public String getExplicitNamespaceAttribute() {
        return "explicit";
    }

    public void setExplicitNamespaceAttribute() {
    }
}
